/*
    readconfig.c

    Defines the prototypes for readconfig and the accoudring structure

    Copyright (C) 2001 Matthias Cramer, cramer@freestone.net
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  
*/

#define BUFSIZE (2048)

#define ALADINEPOCH (765766976)

typedef struct s_aladin {
	char type;
	char * name;
} t_aladin;

const t_aladin aladintype[] = {
   { 0x1c, "Aladin Air" },
   { 0x1e, "Aladin Sport" },
   { 0x3e, "Aladin Sport" },
   { 0x1f, "Aladin Pro" },
   { 0x3f, "Aladin Pro" },
   { 0x34, "Aladin Air X" },
   { 0x44, "Aladin Air X" },
   { 0xa4, "Aladin Air X O2" },
   { 0xf4, "Aladin Air X Nitrox" },
   { 0xff, "Aladin Pro Nitrox" },
   { 0,    NULL }
};

int aladinaltitudes[] = {
  0, 900, 1750, 2700
};

struct s_aladinsettings {
    char        model;
    char        is_air;
    char        is_nitrox;
    char        is_o2;
    
    /* O2 */
    char        workload;   
    char        sensitivity;       
    /* end O2 */
    
    char        beep;
    char        units; 
    
    /* O2 */
    char        premixreset;
    /* Nitrox */
    char        po2max;   

    char        reserve;   
    char        brethwarning;
    unsigned int       serial;
};
  
struct s_aladinstatus {
    unsigned int       battery;
    unsigned char       batterystatus;
    unsigned int        totaldives;
    unsigned int  	logbookoffset;
    char        	numprofiles;
    unsigned int        endringbuf;
    time_t              time;
};

struct s_aladinlogbook {
    unsigned int divenum;
    unsigned char altitude;
    char sos;
    char workalarm;
    char decoalarm;
    char repeatd;
    char acentwaring;
    char bottomtime;
    float maxdepth;
    char surfaceh;
    char surfacem;
    float airconsumption;
    time_t entrytime;
    float watertemp;
};

struct s_profwarnings {
    unsigned char transmit;
    unsigned char work;
    unsigned char decomissed;
    unsigned char ascent;
    unsigned char bottom;
    unsigned char decostop;
};

struct s_profdeco {
    unsigned char physeffort;
    char skincooling;
    unsigned char microbubble;
};

struct s_aladinprofile {
    unsigned int divenum;
    float ambienttemp;
    unsigned int tissue1;
    unsigned int tissue2;
    unsigned int tissue3;
    unsigned int tissue4;
    unsigned int tissue5;
    unsigned int tissue6;
    unsigned int tissue7;
    unsigned int tissue8;
    
    unsigned int microbubbles;
    unsigned int intrapulmenary;

    unsigned char skincool;
    
    /* Nitrox & O2 */
    unsigned char cnso2;
    unsigned char nitroxmix;
    unsigned int ppO2max;
    
    /* O2 only */
    unsigned char workload;
    unsigned char scrsens;
    
    float diveprofile[700];
    struct s_profwarnings warnings[700];
    
    struct s_profdeco decoinfo[230];
    
    /* O2 only */
    unsigned char o2mix [230];
    
    int profilesamples;      
};

